@@ -6,10 +6,10 @@ from integration.helpers.exception import StatusCodeError
 
 
 from integration.helpers.resource import current_region_does_not_support
-from integration.config.service_names import REST_API
+from integration.config.service_names import REST_API, API_KEY
 
 
-@skipIf(current_region_does_not_support([REST_API]), "RestApi is not supported in this testing region")
+@skipIf(current_region_does_not_support([REST_API, API_KEY]), "RestApi/ApiKey is not supported in this testing region")
 class TestApiWithAuthorizerApiKey(BaseTest):
     def test_authorizer_apikey(self):
         self.create_and_verify_stack("combination/api_with_authorizer_apikey")
