@@ -1,8 +1,14 @@
+from unittest.case import skipIf
 from parameterized import parameterized
 
 from integration.helpers.base_test import BaseTest
 
 
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import REST_API
+
+
+@skipIf(current_region_does_not_support([REST_API]), "RestApi is not supported in this testing region")
 class TestApiWithDisableExecuteApiEndpoint(BaseTest):
     @parameterized.expand(
         [
