@@ -3,10 +3,13 @@ from unittest.case import skipIf
 from integration.helpers.base_test import BaseTest
 from integration.helpers.common_api import get_policy_statements, get_queue_policy
 from integration.helpers.resource import current_region_does_not_support
-from integration.config.service_names import CWE_CWS_DLQ
+from integration.config.service_names import CWE_CWS_DLQ, STATE_MACHINE_CWE_CWS
 
 
-@skipIf(current_region_does_not_support([CWE_CWS_DLQ]), "CweCwsDlq is not supported in this testing region")
+@skipIf(
+    current_region_does_not_support([CWE_CWS_DLQ, STATE_MACHINE_CWE_CWS]),
+    "CweCwsDlq is not supported in this testing region",
+)
 class TestStateMachineWithCweDlqGenerated(BaseTest):
     def test_state_machine_with_cwe(self):
         self.create_and_verify_stack("combination/state_machine_with_cwe_dlq_generated")
